@@ -125,7 +125,6 @@ int hnbgw_vty_go_parent(struct vty *vty)
 
 static void _show_cnlink(struct vty *vty, struct hnbgw_cnlink *cnlink)
 {
-	struct osmo_ss7_route *rt;
 	struct osmo_ss7_instance *ss7;
 
 	if (!cnlink) {
@@ -158,8 +157,6 @@ static void _show_cnlink(struct vty *vty, struct hnbgw_cnlink *cnlink)
 		hnbgw_cnlink_sccp_addr_to_str(cnlink, &cnlink->remote_addr),
 		VTY_NEWLINE);
 
-	rt = osmo_ss7_route_lookup(ss7, cnlink->remote_addr.pc);
-	vty_out(vty, "      SS7 route: %s%s", osmo_ss7_route_name(rt, true), VTY_NEWLINE);
 	vty_out(vty, "      RANAP state: %s%s", osmo_fsm_inst_state_name(cnlink->fi), VTY_NEWLINE);
 }
 
@@ -308,8 +305,8 @@ DEFUN(cfg_hnbgw_iuh_local_ip, cfg_hnbgw_iuh_local_ip_cmd, "local-ip A.B.C.D",
       "Accept Iuh connections on local interface\n"
       "Local interface IP address (default: " HNBGW_LOCAL_IP_DEFAULT ")")
 {
-	talloc_free((void *)g_hnbgw->config.iuh_local_ip);
-	g_hnbgw->config.iuh_local_ip = talloc_strdup(g_hnbgw, argv[0]);
+	talloc_free((void *)g_hnbgw->config.iuh.local_ip);
+	g_hnbgw->config.iuh.local_ip = talloc_strdup(g_hnbgw, argv[0]);
 	return CMD_SUCCESS;
 }
 
@@ -317,7 +314,19 @@ DEFUN(cfg_hnbgw_iuh_local_port, cfg_hnbgw_iuh_local_port_cmd, "local-port <1-655
       "Accept Iuh connections on local port\n"
       "Local interface port (default: 29169)")
 {
-	g_hnbgw->config.iuh_local_port = atoi(argv[0]);
+	g_hnbgw->config.iuh.local_port = atoi(argv[0]);
+	return CMD_SUCCESS;
+}
+
+DEFUN(cfg_hnbgw_iuh_tx_queue_max_length, cfg_hnbgw_iuh_tx_queue_max_length_cmd,
+      "tx-queue-max-length <0-65535>",
+      "Maximum transmit queue length, in msgbs\n"
+      "Amount of msgbs which can be queued at maximum in the transmit queue\n")
+{
+	g_hnbgw->config.iuh.tx_queue_max_length = atoi(argv[0]);
+	if (g_hnbgw->iuh)
+		osmo_stream_srv_link_set_tx_queue_max_length(g_hnbgw->iuh,
+							     g_hnbgw->config.iuh.tx_queue_max_length);
 	return CMD_SUCCESS;
 }
 
@@ -327,7 +336,7 @@ DEFUN(cfg_hnbgw_iuh_hnbap_allow_tmsi, cfg_hnbgw_iuh_hnbap_allow_tmsi_cmd,
       "Only accept IMSI identity, reject TMSI or PTMSI\n"
       "Accept IMSI, TMSI or PTMSI as UE identity (default)\n")
 {
-	g_hnbgw->config.hnbap_allow_tmsi = (*argv[0] == '1');
+	g_hnbgw->config.iuh.hnbap_allow_tmsi = (*argv[0] == '1');
 	return CMD_SUCCESS;
 }
 
@@ -1034,15 +1043,18 @@ static int config_write_hnbgw_iuh(struct vty *vty)
 
 	vty_out(vty, " iuh%s", VTY_NEWLINE);
 
-	addr = g_hnbgw->config.iuh_local_ip;
+	addr = g_hnbgw->config.iuh.local_ip;
 	if (addr && (strcmp(addr, HNBGW_LOCAL_IP_DEFAULT) != 0))
 		vty_out(vty, "  local-ip %s%s", addr, VTY_NEWLINE);
 
-	port = g_hnbgw->config.iuh_local_port;
+	port = g_hnbgw->config.iuh.local_port;
 	if (port && port != IUH_DEFAULT_SCTP_PORT)
 		vty_out(vty, "  local-port %u%s", port, VTY_NEWLINE);
 
-	if (!g_hnbgw->config.hnbap_allow_tmsi)
+	if (g_hnbgw->config.iuh.tx_queue_max_length != IUH_TX_QUEUE_MAX_LENGTH)
+		vty_out(vty, "  tx-queue-max-length %u%s", g_hnbgw->config.iuh.tx_queue_max_length, VTY_NEWLINE);
+
+	if (!g_hnbgw->config.iuh.hnbap_allow_tmsi)
 		vty_out(vty, "  hnbap-allow-tmsi 0%s", VTY_NEWLINE);
 
 	return CMD_SUCCESS;
@@ -1128,6 +1140,7 @@ void hnbgw_vty_init(void)
 
 	install_element(IUH_NODE, &cfg_hnbgw_iuh_local_ip_cmd);
 	install_element(IUH_NODE, &cfg_hnbgw_iuh_local_port_cmd);
+	install_element(IUH_NODE, &cfg_hnbgw_iuh_tx_queue_max_length_cmd);
 	install_element(IUH_NODE, &cfg_hnbgw_iuh_hnbap_allow_tmsi_cmd);
 
 	install_element(HNBGW_NODE, &cfg_hnbgw_iucs_cmd);
